#include "mainwindow.h"
#include "messages.h"


MainWindow::MainWindow() : os::Window( os::Rect( 0, 0, 700, 300 ), "main_wnd", "FTP Client" )
{
	SetupMenus();
	SetupToolBar();
	
	SetupStatusBar();
	Layout();
	

	/* Set Icon */
	os::Resources cCol( get_image_id() );
	os::ResStream *pcStream = cCol.GetResourceStream( "icon48x48.png" );
	os::BitmapImage *pcIcon = new os::BitmapImage( pcStream );
	SetIcon( pcIcon->LockBitmap() );
	delete( pcIcon );

}

void MainWindow::SetupMenus()
{
	m_pcMainMenu = new os::Menu(os::Rect(0,0,1,1),"main_menu", os::ITEMS_IN_ROW);
	
	os::Menu* file = new os::Menu(os::Rect(0,0,1,1),"File",os::ITEMS_IN_COLUMN);
	file->AddItem("About",new os::Message(M_APP_ABOUT));
	file->AddItem(new os::MenuSeparator());
	file->AddItem("Quit",new os::Message(M_APP_QUIT));
	
	
	os::Menu* edit = new os::Menu(os::Rect(0,0,1,1),"Edit",os::ITEMS_IN_COLUMN);


	os::Menu* help = new os::Menu(os::Rect(0,0,1,1),"Help",os::ITEMS_IN_COLUMN);

	m_pcMainMenu->AddItem(file);
	m_pcMainMenu->AddItem(edit);
	m_pcMainMenu->AddItem(help);
		
	
	m_pcMainMenu->SetTargetForItems(this);
	m_pcMainMenu->ResizeTo(os::Point(GetBounds().Width(),m_pcMainMenu->GetPreferredSize(false).y));
	AddChild(m_pcMainMenu);
}

void MainWindow::SetupToolBar()
{
	m_pcToolBar = new os::ToolBar(os::Rect(),"toolbar");
	m_pcToolBar->AddChild(m_pcConnectBar = new ConnectBar(),os::ToolBar::TB_FIXED_WIDTH);
	m_pcToolBar->SetFrame( os::Rect(0,m_pcMainMenu->GetBounds().Height()+1,GetBounds().Width(),m_pcMainMenu->GetBounds().Height()+1+m_pcToolBar->GetPreferredSize(false).y));
	AddChild(m_pcToolBar);
}

void MainWindow::SetupStatusBar()
{
	m_pcStatusBar = new os::StatusBar(os::Rect(0,GetBounds().Height()-20,GetBounds().Width(),GetBounds().Height()),"",os::CF_FOLLOW_LEFT | os::CF_FOLLOW_RIGHT | os::CF_FOLLOW_BOTTOM);
	m_pcStatusBar->AddPanel("status","status");
	AddChild(m_pcStatusBar);
}

void MainWindow::Layout()
{
	m_pcView = new FTPView(os::Rect(0,(int)m_pcMainMenu->GetBounds().Height() + (int)m_pcToolBar->GetBounds().Height() + 1,GetBounds().Width(),GetBounds().Height()-20),"container_view");
	AddChild(m_pcView);
}


void MainWindow::HandleMessage( os::Message* pcMessage )
{
	switch( pcMessage->GetCode() )
	{
		case M_APP_ABOUT:
		{
			break;
		}
		
		case M_APP_QUIT:
		{
			PostMessage( os::M_QUIT );
			break;
		}
		
		case M_CONNECT:
		{
			//add connection code here
			break;
		}
	}
}
bool MainWindow::OkToQuit()
{
	os::Application::GetInstance()->PostMessage( os::M_QUIT );
	return( true );
}


















